==> ecs-1.100.0-sources.jar: software/amazon/awscdk/services/ecs/BottleRocketImageProps.java <==
package software.amazon.awscdk.services.ecs;

/**
 * Properties for BottleRocketImage.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:41.758Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.BottleRocketImageProps")
@software.amazon.jsii.Jsii.Proxy(BottleRocketImageProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BottleRocketImageProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Amazon ECS variant to use.
     * <p>
     * Only <code>aws-ecs-1</code> is currently available
     * <p>
     * Default: - BottlerocketEcsVariant.AWS_ECS_1
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.BottlerocketEcsVariant getVariant() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BottleRocketImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BottleRocketImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BottleRocketImageProps> {
        private software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant;

        /**
         * Sets the value of {@link BottleRocketImageProps#getVariant}
         * @param variant The Amazon ECS variant to use.
         *                Only <code>aws-ecs-1</code> is currently available
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder variant(software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant) {
            this.variant = variant;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BottleRocketImageProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BottleRocketImageProps build() {
            return new Jsii$Proxy(variant);
        }
    }

    /**
     * An implementation for {@link BottleRocketImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BottleRocketImageProps {
        private final software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.variant = software.amazon.jsii.Kernel.get(this, "variant", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.BottlerocketEcsVariant.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.variant = variant;
        }

        @Override
        public final software.amazon.awscdk.services.ecs.BottlerocketEcsVariant getVariant() {
            return this.variant;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getVariant() != null) {
                data.set("variant", om.valueToTree(this.getVariant()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.BottleRocketImageProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BottleRocketImageProps.Jsii$Proxy that = (BottleRocketImageProps.Jsii$Proxy) o;

            return this.variant != null ? this.variant.equals(that.variant) : that.variant == null;
        }

        @Override
        public final int hashCode() {
            int result = this.variant != null ? this.variant.hashCode() : 0;
            return result;
        }
    }
}

==> ecs-1.122.0-sources.jar: software/amazon/awscdk/services/ecs/BottleRocketImageProps.java <==
package software.amazon.awscdk.services.ecs;

/**
 * Properties for BottleRocketImage.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-08T20:44:44.441Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.BottleRocketImageProps")
@software.amazon.jsii.Jsii.Proxy(BottleRocketImageProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BottleRocketImageProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The CPU architecture.
     * <p>
     * Default: - x86_64
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.InstanceArchitecture getArchitecture() {
        return null;
    }

    /**
     * The Amazon ECS variant to use.
     * <p>
     * Only <code>aws-ecs-1</code> is currently available
     * <p>
     * Default: - BottlerocketEcsVariant.AWS_ECS_1
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.BottlerocketEcsVariant getVariant() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BottleRocketImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BottleRocketImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BottleRocketImageProps> {
        private software.amazon.awscdk.services.ec2.InstanceArchitecture architecture;
        private software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant;

        /**
         * Sets the value of {@link BottleRocketImageProps#getArchitecture}
         * @param architecture The CPU architecture.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder architecture(software.amazon.awscdk.services.ec2.InstanceArchitecture architecture) {
            this.architecture = architecture;
            return this;
        }

        /**
         * Sets the value of {@link BottleRocketImageProps#getVariant}
         * @param variant The Amazon ECS variant to use.
         *                Only <code>aws-ecs-1</code> is currently available
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder variant(software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant) {
            this.variant = variant;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BottleRocketImageProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BottleRocketImageProps build() {
            return new Jsii$Proxy(architecture, variant);
        }
    }

    /**
     * An implementation for {@link BottleRocketImageProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BottleRocketImageProps {
        private final software.amazon.awscdk.services.ec2.InstanceArchitecture architecture;
        private final software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.architecture = software.amazon.jsii.Kernel.get(this, "architecture", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.InstanceArchitecture.class));
            this.variant = software.amazon.jsii.Kernel.get(this, "variant", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.BottlerocketEcsVariant.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.ec2.InstanceArchitecture architecture, final software.amazon.awscdk.services.ecs.BottlerocketEcsVariant variant) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.architecture = architecture;
            this.variant = variant;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.InstanceArchitecture getArchitecture() {
            return this.architecture;
        }

        @Override
        public final software.amazon.awscdk.services.ecs.BottlerocketEcsVariant getVariant() {
            return this.variant;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getArchitecture() != null) {
                data.set("architecture", om.valueToTree(this.getArchitecture()));
            }
            if (this.getVariant() != null) {
                data.set("variant", om.valueToTree(this.getVariant()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.BottleRocketImageProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BottleRocketImageProps.Jsii$Proxy that = (BottleRocketImageProps.Jsii$Proxy) o;

            if (this.architecture != null ? !this.architecture.equals(that.architecture) : that.architecture != null) return false;
            return this.variant != null ? this.variant.equals(that.variant) : that.variant == null;
        }

        @Override
        public final int hashCode() {
            int result = this.architecture != null ? this.architecture.hashCode() : 0;
            result = 31 * result + (this.variant != null ? this.variant.hashCode() : 0);
            return result;
        }
    }
}
